@@ -2,7 +2,7 @@ import asyncio
 import inspect
 import functools
 
-from typing import TYPE_CHECKING, Any, Callable, cast, Coroutine, TypeVar
+from typing import TYPE_CHECKING, Any, Callable, Coroutine, TypeVar
 
 if TYPE_CHECKING:
     from typing_extensions import ParamSpec
@@ -45,14 +45,15 @@ def asyncify_func(func: "Callable[P, T]") -> "Callable[P, Coroutine[Any, Any, T]
         get = asyncify.asyncify_func(requests.get)
 
     .. note::
-
         This function uses the default loop executor.
         Change it with `loop.set_default_executor <https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.set_default_executor>`_.
-    """
-    if inspect.iscoroutinefunction(func):
-        return cast("Callable[P, Coroutine[Any, Any, T]]", func)
 
-    if not callable(func):
+    Raises
+    -------
+    TypeError
+        The object passed in was not a function.
+    """
+    if not inspect.isfunction(func):
         raise TypeError('Expected a callable function, not {!r}'.format(func))
 
     @functools.wraps(func)
@@ -94,13 +95,15 @@ def syncify_func(func: "Callable[P, Coroutine[Any, Any, T]]") -> "Callable[P, T]
             loop = asyncio.get_event_loop()
             loop.run_until_complete(coroutine_func())
 
-    .. note::
+    .. warning::
         There must be a running event loop.
-    """
-    if inspect.isfunction(func) and not inspect.iscoroutinefunction(func):
-        return func
 
-    if not callable(func):
+    Raises
+    -------
+    TypeError
+        The object passed was not a coroutine function.
+    """
+    if not inspect.isfunction(func):
         raise TypeError('Expected a callable function, not {!r}'.format(func))
 
     @functools.wraps(func)
