@@ -1,4 +1,19 @@
-from typing import Any, Awaitable, Callable, Generator, Generic, Iterable, Iterator, List, TypeVar, Optional
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Generator,
+    Generic,
+    Iterable,
+    Iterator,
+    List,
+    NoReturn,
+    TypeVar,
+    Optional,
+)
+
+if TYPE_CHECKING:
+    from typing_extensions import Self
+    from ._types import NoArgAwaitable
 
 
 __all__ = ('AsyncIterable', 'async_iter')
@@ -12,8 +27,8 @@ class AsyncIterable(Generic[T]):
         self,
         iterable: Iterable[T],
         *,
-        before: Optional[Callable[[], Awaitable]] = None,
-        after: Optional[Callable[[], Awaitable]] = None
+        before: Optional["NoArgAwaitable[Any]"] = None,
+        after: Optional["NoArgAwaitable[Any]"] = None,
     ):
         self.iterable = iterable
         self.iterator: Optional[Iterator[T]] = None
@@ -24,7 +39,10 @@ class AsyncIterable(Generic[T]):
     def __await__(self) -> Generator[Any, Any, List[T]]:
         return self.flatten().__await__()
 
-    def __aiter__(self):
+    def __iter__(self) -> NoReturn:
+        raise TypeError(f'{self.__class__.__name__!r} object is not iterable, use async for instead.')
+
+    def __aiter__(self) -> "Self":
         self.iterator = iter(self.iterable)
         return self
 
@@ -51,19 +69,19 @@ class AsyncIterable(Generic[T]):
 
 def async_iter(
     iterable: Iterable[T],
-    before: Optional[Callable[[], Awaitable]] = None,
-    after: Optional[Callable[[], Awaitable]] = None,
+    before: Optional["NoArgAwaitable[Any]"] = None,
+    after: Optional["NoArgAwaitable[Any]"] = None,
 ) -> AsyncIterable[T]:
     """
-    Asynchronously iterate through an iterable while calling a callback in before and/or each iteration.
+    Asynchronously iterate through an iterable while calling an async callback before and/or after each iteration.
 
     Parameters
     ------------
     iterable: :class:`Iterable`
         The iterable to iterator over.
-    before: Optional[``Callable[<no_parameters>, Awaitable]``]
+    before: Optional[``Callable[<no_parameters>, Awaitable[Any]]``]
         The optional asynchronous callable for before the iteration.
-    after: Optional[``Callable[<no_parameters>, Awaitable]``]
+    after: Optional[``Callable[<no_parameters>, Awaitable[Any]]``]
         The optional asynchronous callable for after the iteration.
 
 
@@ -83,8 +101,13 @@ def async_iter(
 
             async for number in async_iter([1, 2, 3], sleep, before=True):
                 print('%d seconds have passed.' % number)
+
+    Raises
+    -------
+    TypeError
+        The object passed was not an iterable.
     """
     if not hasattr(iterable, '__iter__'):
-        raise TypeError('Expected object with __iter__, not {!r}'.format(iterable))
+        raise TypeError('Expected iterable object, not {!r}'.format(iterable))
 
     return AsyncIterable(iterable, before=before, after=after)
